@@ -111,6 +111,13 @@ namespace @{namespace}
     float random_float();
     int random_int(int min, int max);
 
+    template <class T>
+    void mg_swap(T& a, T& b)
+    {
+        std::swap(a, b);
+    }
+
+
     // Converters
     template <typename T> T strTo(const std::string &value);
     template <typename T> std::string toStr(T value);
@@ -146,7 +153,7 @@ namespace @{namespace}
     }
 
     std::string format(const char *fmt, ...);
-    
+
     {{format=json}}
     template <class TType>
     std::string serialize_command_to_json(intrusive_ptr<TType> command)
@@ -154,19 +161,19 @@ namespace @{namespace}
         Json::Value json;
         SerializerJson serializer(json[command->get_type()]);
         command->serialize_json(serializer);
-        
+
         Json::StreamWriterBuilder wbuilder;
         wbuilder["indentation"] = "";
         return Json::writeString(wbuilder, json);
     }
-    
+
     template <class TType>
     static intrusive_ptr<TType> create_command_from_json(const std::string& payload)
     {
         Json::Value json;
         Json::Reader reader;
         reader.parse(payload, json);
-        
+
         auto type = json.getMemberNames()[0];
         DeserializerJson deserializer(json[type]);
         auto command = Factory::shared().build<TType>(type);
@@ -184,7 +191,7 @@ namespace @{namespace}
         return clone;
     }
     {{end_format=json}}
-    
+
     {{format=xml}}
     template <class TType>
     static std::string serialize_command_to_xml(intrusive_ptr<TType> command)
@@ -193,7 +200,7 @@ namespace @{namespace}
         auto root = doc.append_child(command->get_type().c_str());
         SerializerXml serializer(root);
         command->serialize_xml(serializer);
-        
+
         std::stringstream stream;
         pugi::xml_writer_stream writer(stream);
 #ifdef NDEBUG
@@ -209,7 +216,7 @@ namespace @{namespace}
 #endif
         return stream.str();
     }
-    
+
     template <class TType>
     static intrusive_ptr<TType> create_command_from_xml(const std::string& payload)
     {
@@ -230,7 +237,7 @@ namespace @{namespace}
         return clone;
     }
     {{end_format=xml}}
-    
+
     {{format=both}}
     template <class TType>
     static std::string serialize_command_to_xml(intrusive_ptr<TType> command)
@@ -239,7 +246,7 @@ namespace @{namespace}
         auto root = doc.append_child(command->get_type().c_str());
         SerializerXml serializer(root);
         command->serialize_xml(serializer);
-        
+
         std::stringstream stream;
         pugi::xml_writer_stream writer(stream);
 #ifdef NDEBUG
@@ -255,7 +262,7 @@ namespace @{namespace}
 #endif
         return stream.str();
     }
-    
+
     template <class TType>
     static intrusive_ptr<TType> create_command_from_xml(const std::string& payload)
     {
@@ -267,26 +274,26 @@ namespace @{namespace}
         command->deserialize_xml(deserializer);
         return command;
     }
-    
+
     template <class TType>
     static std::string serialize_command_to_json(intrusive_ptr<TType> command)
     {
         Json::Value json;
         SerializerJson serializer(json[command->get_type()]);
         command->serialize_json(serializer);
-        
+
         Json::StreamWriterBuilder wbuilder;
         wbuilder["indentation"] = "";
         return Json::writeString(wbuilder, json);
     }
-    
+
     template <class TType>
     static intrusive_ptr<TType> create_command_from_json(const std::string& payload)
     {
         Json::Value json;
         Json::Reader reader;
         reader.parse(payload, json);
-        
+
         auto type = json.getMemberNames()[0];
         DeserializerJson deserializer(json[type]);
         auto command = Factory::shared().build<TType>(type);
@@ -296,7 +303,7 @@ namespace @{namespace}
         }
         return command;
     }
-    
+
     template <class TType>
     static intrusive_ptr<TType> clone_object(intrusive_ptr<TType> object)
     {
@@ -732,7 +739,7 @@ FACTORY_HPP = '''#ifndef __@{namespace}_Factory_h__
 @{registration}
 namespace @{namespace}
 {
-    
+
     class Factory
     {
         class IBuilder
@@ -741,7 +748,7 @@ namespace @{namespace}
             virtual ~IBuilder() {}
             virtual void* build() = 0;
         };
-        
+
         template<class TType>
         class Builder : public IBuilder
         {
@@ -751,7 +758,7 @@ namespace @{namespace}
                 return new TType();
             };
         };
-        
+
         ~Factory()
         {
             for(auto& pair : _builders)
@@ -766,7 +773,7 @@ namespace @{namespace}
             static Factory instance;
             return instance;
         }
-        
+
         template <class TType>
         void registrationCommand( const std::string & key )
         {
@@ -777,7 +784,7 @@ namespace @{namespace}
             assert( _builders.find( key ) == _builders.end() );
             _builders[key] = new Builder<TType>();
         };
-        
+
         template <class TType>
         intrusive_ptr<TType> build( const std::string & key ) const
         {
@@ -904,7 +911,7 @@ public:
             item.serialize(value, "value", default_value::value<T>());
         }
     }
-    
+
     template <class T>
     typename std::enable_if<is_attribute<T>::value && std::is_same<T, bool>::value, void>::type
     serialize(const std::vector<T>& values, const std::string& key)
@@ -976,7 +983,7 @@ public:
         {
             SerializerXml item = child.add_child("pair");
             item.add_attribute("key", pair.first, default_value::value<Key>());
-            item.add_attribute("value", pair.second, default_value::value<Value>());            
+            item.add_attribute("value", pair.second, default_value::value<Value>());
         }
     }
 
@@ -991,7 +998,7 @@ public:
         {
             SerializerXml item = child.add_child("pair");
             item.add_attribute("key", pair.first, default_value::value<Key>());
-            item.add_attribute("value", pair.second.str(), default_value::value<std::string>());            
+            item.add_attribute("value", pair.second.str(), default_value::value<std::string>());
         }
     }
 
@@ -1006,7 +1013,7 @@ public:
         {
             SerializerXml item = child.add_child("pair");
             item.add_attribute("key", pair.first, default_value::value<Key>());
-            item.add_attribute("value", pair.second ? pair.second->name : "", default_value::value<std::string>());            
+            item.add_attribute("value", pair.second ? pair.second->name : "", default_value::value<std::string>());
         }
     }
 
@@ -1021,7 +1028,7 @@ public:
         {
             SerializerXml item = child.add_child("pair");
             item.add_attribute("key", pair.first, default_value::value<Key>());
-            item.serialize(pair.second, "value");            
+            item.serialize(pair.second, "value");
         }
     }
 
@@ -1036,7 +1043,7 @@ public:
         {
             SerializerXml item = child.add_child("pair");
             item.add_attribute("key", pair.first.str(), default_value::value<std::string>());
-            item.add_attribute("value", pair.second, default_value::value<Value>());            
+            item.add_attribute("value", pair.second, default_value::value<Value>());
         }
     }
 
@@ -1051,7 +1058,7 @@ public:
         {
             SerializerXml item = child.add_child("pair");
             item.add_attribute("key", pair.first.str(), default_value::value<std::string>());
-            item.add_attribute("value", pair.second.str(), default_value::value<std::string>());            
+            item.add_attribute("value", pair.second.str(), default_value::value<std::string>());
         }
     }
 
@@ -1066,7 +1073,7 @@ public:
         {
             SerializerXml item = child.add_child("pair");
             item.add_attribute("key", pair.first.str(), default_value::value<std::string>());
-            item.add_attribute("value", pair.second ? pair.second->name : "", default_value::value<std::string>());            
+            item.add_attribute("value", pair.second ? pair.second->name : "", default_value::value<std::string>());
         }
     }
 
@@ -1081,7 +1088,7 @@ public:
         {
             SerializerXml item = child.add_child("pair");
             item.add_attribute("key", pair.first.str(), default_value::value<std::string>());
-            item.serialize(pair.second, "value");            
+            item.serialize(pair.second, "value");
         }
     }
 
@@ -1096,7 +1103,7 @@ public:
         {
             SerializerXml item = child.add_child("pair");
             item.add_attribute("key", pair.first ? pair.first->name : "", default_value::value<std::string>());
-            item.add_attribute("value", pair.second, default_value::value<Value>());            
+            item.add_attribute("value", pair.second, default_value::value<Value>());
         }
     }
 
@@ -1111,7 +1118,7 @@ public:
         {
             SerializerXml item = child.add_child("pair");
             item.add_attribute("key", pair.first ? pair.first->name : "", default_value::value<std::string>());
-            item.add_attribute("value", pair.second.str(), default_value::value<std::string>());            
+            item.add_attribute("value", pair.second.str(), default_value::value<std::string>());
         }
     }
 
@@ -1126,7 +1133,7 @@ public:
         {
             SerializerXml item = child.add_child("pair");
             item.add_attribute("key", pair.first ? pair.first->name : "", default_value::value<std::string>());
-            item.add_attribute("value", pair.second ? pair.second->name : "", default_value::value<std::string>());            
+            item.add_attribute("value", pair.second ? pair.second->name : "", default_value::value<std::string>());
         }
     }
 
@@ -1141,7 +1148,7 @@ public:
         {
             SerializerXml item = child.add_child("pair");
             item.add_attribute("key", pair.first ? pair.first->name : "", default_value::value<std::string>());
-            item.serialize(pair.second, "value");            
+            item.serialize(pair.second, "value");
         }
     }
 
@@ -1156,7 +1163,7 @@ public:
         {
             SerializerXml item = child.add_child("pair");
             item.serialize(pair.first, "key");
-            item.add_attribute("value", pair.second, default_value::value<Value>());            
+            item.add_attribute("value", pair.second, default_value::value<Value>());
         }
     }
 
@@ -1171,7 +1178,7 @@ public:
         {
             SerializerXml item = child.add_child("pair");
             item.serialize(pair.first, "key");
-            item.add_attribute("value", pair.second.str(), default_value::value<std::string>());            
+            item.add_attribute("value", pair.second.str(), default_value::value<std::string>());
         }
     }
 
@@ -1201,7 +1208,7 @@ public:
         {
             SerializerXml item = child.add_child("pair");
             item.serialize(pair.first, "key");
-            item.serialize(pair.second, "value");            
+            item.serialize(pair.second, "value");
         }
     }
 /* Maps serialization finish */
@@ -1349,7 +1356,7 @@ public:
         {
             Key key_ = item.get_attribute("key", default_value::value<Key>());
             Value value_ = item.get_attribute("value", default_value::value<Value>());
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -1362,7 +1369,7 @@ public:
         {
             Key key_ = item.get_attribute("key", default_value::value<Key>());
             Value value_; item.deserialize(value_, "value");
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -1388,7 +1395,7 @@ public:
         {
             Key key_ = item.get_attribute("key", default_value::value<Key>());
             Value value_; item.deserialize(value_, "value");
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -1401,7 +1408,7 @@ public:
         {
             Key key_; item.deserialize(key_, "key");
             Value value_ = item.get_attribute("value", default_value::value<Value>());
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -1414,7 +1421,7 @@ public:
         {
             Key key_; item.deserialize(key_, "key");
             Value value_; item.deserialize(value_, "value");
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -1427,7 +1434,7 @@ public:
         {
             Key key_; item.deserialize(key_, "key");
             Value value_ = DataStorage::shared().get<typename data_type<Value>::type>(item.get_attribute("value", default_value::value<std::string>()));
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -1440,7 +1447,7 @@ public:
         {
             Key key_; item.deserialize(key_, "key");
             Value value_; item.deserialize(value_, "value");
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -1453,7 +1460,7 @@ public:
         {
             Key key_ = DataStorage::shared().get<typename data_type<Key>::type>(item.get_attribute("key", default_value::value<std::string>()));
             Value value_ = item.get_attribute("value", default_value::value<Value>());
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -1466,7 +1473,7 @@ public:
         {
             Key key_ = DataStorage::shared().get<typename data_type<Key>::type>(item.get_attribute("key", default_value::value<std::string>()));
             Value value_; item.deserialize(value_, "value");
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -1479,7 +1486,7 @@ public:
         {
             Key key_ = DataStorage::shared().get<typename data_type<Key>::type>(item.get_attribute("key", default_value::value<std::string>()));
             Value value_ = DataStorage::shared().get<typename data_type<Value>::type>(item.get_attribute("value", default_value::value<std::string>()));
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -1492,7 +1499,7 @@ public:
         {
             Key key_ = DataStorage::shared().get<typename data_type<Key>::type>(item.get_attribute("key", default_value::value<std::string>()));
             Value value_; item.deserialize(value_, "value");
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -1505,7 +1512,7 @@ public:
         {
             Key key_; item.deserialize(key_, "key");
             Value value_ = item.get_attribute("value", default_value::value<Value>());
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -1518,7 +1525,7 @@ public:
         {
             Key key_; item.deserialize(key_, "key");
             Value value_; item.deserialize(value_, "value");
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -1531,7 +1538,7 @@ public:
         {
             Key key_; item.deserialize(key_, "key");
             Value value_ = DataStorage::shared().get<typename data_type<Value>::type>(item.get_attribute("value", default_value::value<std::string>()));
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -1544,7 +1551,7 @@ public:
         {
             Key key_; item.deserialize(key_, "key");
             Value value_; item.deserialize(value_, "value");
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 /* Maps deserialization finish */
@@ -1894,7 +1901,7 @@ public:
         {
             SerializerJson item = child.add_array_item();
             item.add_attribute("key", pair.first, default_value::value<Key>());
-            item.add_attribute("value", pair.second, default_value::value<Value>());            
+            item.add_attribute("value", pair.second, default_value::value<Value>());
         }
     }
 
@@ -1909,7 +1916,7 @@ public:
         {
             SerializerJson item = child.add_array_item();
             item.add_attribute("key", pair.first, default_value::value<Key>());
-            item.add_attribute("value", pair.second.str(), default_value::value<std::string>());            
+            item.add_attribute("value", pair.second.str(), default_value::value<std::string>());
         }
     }
 
@@ -1924,7 +1931,7 @@ public:
         {
             SerializerJson item = child.add_array_item();
             item.add_attribute("key", pair.first, default_value::value<Key>());
-            item.add_attribute("key", pair.second ? pair.second->name : "", default_value::value<std::string>());            
+            item.add_attribute("value", pair.second ? pair.second->name : "", default_value::value<std::string>());
         }
     }
 
@@ -1939,7 +1946,7 @@ public:
         {
             SerializerJson item = child.add_array_item();
             item.add_attribute("key", pair.first, default_value::value<Key>());
-            item.serialize(pair.second, "value");            
+            item.serialize(pair.second, "value");
         }
     }
 
@@ -1954,7 +1961,7 @@ public:
         {
             SerializerJson item = child.add_array_item();
             item.add_attribute("key", pair.first.str(), default_value::value<std::string>());
-            item.add_attribute("value", pair.second, default_value::value<Value>());            
+            item.add_attribute("value", pair.second, default_value::value<Value>());
         }
     }
 
@@ -1969,7 +1976,7 @@ public:
         {
             SerializerJson item = child.add_array_item();
             item.add_attribute("key", pair.first.str(), default_value::value<std::string>());
-            item.add_attribute("value", pair.second.str(), default_value::value<std::string>());            
+            item.add_attribute("value", pair.second.str(), default_value::value<std::string>());
         }
     }
 
@@ -1984,7 +1991,7 @@ public:
         {
             SerializerJson item = child.add_array_item();
             item.add_attribute("key", pair.first.str(), default_value::value<std::string>());
-            item.add_attribute("key", pair.second ? pair.second->name : "", default_value::value<std::string>());            
+            item.add_attribute("value", pair.second ? pair.second->name : "", default_value::value<std::string>());
         }
     }
 
@@ -1999,7 +2006,7 @@ public:
         {
             SerializerJson item = child.add_array_item();
             item.add_attribute("key", pair.first.str(), default_value::value<std::string>());
-            item.serialize(pair.second, "value");            
+            item.serialize(pair.second, "value");
         }
     }
 
@@ -2014,7 +2021,7 @@ public:
         {
             SerializerJson item = child.add_array_item();
             item.add_attribute("key", pair.first ? pair.first->name : "", default_value::value<std::string>());
-            item.add_attribute("value", pair.second, default_value::value<Value>());            
+            item.add_attribute("value", pair.second, default_value::value<Value>());
         }
     }
 
@@ -2029,7 +2036,7 @@ public:
         {
             SerializerJson item = child.add_array_item();
             item.add_attribute("key", pair.first ? pair.first->name : "", default_value::value<std::string>());
-            item.add_attribute("value", pair.second.str(), default_value::value<std::string>());            
+            item.add_attribute("value", pair.second.str(), default_value::value<std::string>());
         }
     }
 
@@ -2044,7 +2051,7 @@ public:
         {
             SerializerJson item = child.add_array_item();
             item.add_attribute("key", pair.first ? pair.first->name : "", default_value::value<std::string>());
-            item.add_attribute("key", pair.second ? pair.second->name : "", default_value::value<std::string>());
+            item.add_attribute("value", pair.second ? pair.second->name : "", default_value::value<std::string>());
         }
     }
 
@@ -2059,7 +2066,7 @@ public:
         {
             SerializerJson item = child.add_array_item();
             item.add_attribute("key", pair.first ? pair.first->name : "", default_value::value<std::string>());
-            item.serialize(pair.second, "value");            
+            item.serialize(pair.second, "value");
         }
     }
 
@@ -2074,7 +2081,7 @@ public:
         {
             SerializerJson item = child.add_array_item();
             item.serialize(pair.first, "key");
-            item.add_attribute("value", pair.second, default_value::value<Value>());            
+            item.add_attribute("value", pair.second, default_value::value<Value>());
         }
     }
 
@@ -2089,7 +2096,7 @@ public:
         {
             SerializerJson item = child.add_array_item();
             item.serialize(pair.first, "key");
-            item.add_attribute("value", pair.second.str(), default_value::value<std::string>());            
+            item.add_attribute("value", pair.second.str(), default_value::value<std::string>());
         }
     }
 
@@ -2104,7 +2111,7 @@ public:
         {
             SerializerJson item = child.add_array_item();
             item.serialize(pair.first, "key");
-            item.add_attribute("value", pair.second ? pair.second->name : "", default_value::value<std::string>());            
+            item.add_attribute("value", pair.second ? pair.second->name : "", default_value::value<std::string>());
         }
     }
 
@@ -2119,7 +2126,7 @@ public:
         {
             SerializerJson item = child.add_array_item();
             item.serialize(pair.first, "key");
-            item.serialize(pair.second, "value");            
+            item.serialize(pair.second, "value");
         }
     }
 /* Maps serialization finish */
@@ -2272,7 +2279,7 @@ public:
         {
             Key key_ = item.get_attribute("key", default_value::value<Key>());
             Value value_ = item.get_attribute("value", default_value::value<Value>());
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -2285,7 +2292,7 @@ public:
         {
             Key key_ = item.get_attribute("key", default_value::value<Key>());
             Value value_; item.deserialize(value_, "value");
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -2298,7 +2305,7 @@ public:
         {
             Key key_ = item.get_attribute("key", default_value::value<Key>());
             Value value_ = DataStorage::shared().get<typename data_type<Value>::type>(item.get_attribute("value", default_value::value<std::string>()));
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -2311,7 +2318,7 @@ public:
         {
             Key key_ = item.get_attribute("key", default_value::value<Key>());
             Value value_; item.deserialize(value_, "value");
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -2324,7 +2331,7 @@ public:
         {
             Key key_; item.deserialize(key_, "key");
             Value value_ = item.get_attribute("value", default_value::value<Value>());
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -2337,7 +2344,7 @@ public:
         {
             Key key_; item.deserialize(key_, "key");
             Value value_; item.deserialize(value_, "value");
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -2350,7 +2357,7 @@ public:
         {
             Key key_; item.deserialize(key_, "key");
             Value value_ = DataStorage::shared().get<typename data_type<Value>::type>(item.get_attribute("value", default_value::value<std::string>()));
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -2363,7 +2370,7 @@ public:
         {
             Key key_; item.deserialize(key_, "key");
             Value value_; item.deserialize(value_, "value");
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -2376,7 +2383,7 @@ public:
         {
             Key key_ = DataStorage::shared().get<typename data_type<Key>::type>(item.get_attribute("key", default_value::value<std::string>()));
             Value value_ = item.get_attribute("value", default_value::value<Value>());
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -2389,7 +2396,7 @@ public:
         {
             Key key_ = DataStorage::shared().get<typename data_type<Key>::type>(item.get_attribute("key", default_value::value<std::string>()));
             Value value_; item.deserialize(value_, "value");
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -2402,7 +2409,7 @@ public:
         {
             Key key_ = DataStorage::shared().get<typename data_type<Key>::type>(item.get_attribute("key", default_value::value<std::string>()));
             Value value_ = DataStorage::shared().get<typename data_type<Value>::type>(item.get_attribute("value", default_value::value<std::string>()));
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -2415,7 +2422,7 @@ public:
         {
             Key key_ = DataStorage::shared().get<typename data_type<Key>::type>(item.get_attribute("key", default_value::value<std::string>()));
             Value value_; item.deserialize(value_, "value");
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -2428,7 +2435,7 @@ public:
         {
             Key key_; item.deserialize(key_, "key");
             Value value_ = item.get_attribute("value", default_value::value<Value>());
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -2441,7 +2448,7 @@ public:
         {
             Key key_; item.deserialize(key_, "key");
             Value value_; item.deserialize(value_, "value");
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -2454,7 +2461,7 @@ public:
         {
             Key key_; item.deserialize(key_, "key");
             Value value_ = DataStorage::shared().get<typename data_type<Value>::type>(item.get_attribute("value", default_value::value<std::string>()));
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 
@@ -2467,7 +2474,7 @@ public:
         {
             Key key_; item.deserialize(key_, "key");
             Value value_; item.deserialize(value_, "value");
-            map[key_] = value_;            
+            map[key_] = value_;
         }
     }
 /* Maps deserialization finish */
@@ -2875,7 +2882,7 @@ public:
     {
         return data();
     }
-    
+
     T& operator *()
     {
         return *data();
