@@ -63,25 +63,25 @@ class RegexPatternPython(object):
     }
     ''', ['list_do_if']),
 
-        (re.compile(r'DataStorage::shared\(\).get<(\w+)>'), r'DataStorage::shared().get\1', ['DataStorage::shared']),
-        (re.compile(r'Factory::(.+)<\w+>'), r'Factory.\1', ['Factory::']),
-        (re.compile(r'for\s*\(\s*\w+[\s&\*]*(\w+)\s*:\s*(.+)\s*\)'), r'for \1 in \2:', ['for']),
-        (re.compile(r'for\s*\(\s*\w+\s*(\w+)=(\w+);\s*\w+<([\.\->\w]+?);\s*\+\+\w+\s*\)'),
+        (re.compile(r'\bDataStorage::shared\(\).get<(\w+)>'), r'DataStorage::shared().get\1', ['DataStorage::shared']),
+        (re.compile(r'\bFactory::(.+)<\w+>'), r'Factory.\1', ['Factory::']),
+        (re.compile(r'\bfor\s*\(\s*\w+[\s&\*]*(\w+)\s*:\s*(.+)\s*\)'), r'for \1 in \2:', ['for']),
+        (re.compile(r'\bfor\s*\(\s*\w+\s*(\w+)=(\w+);\s*\w+<([\.\->\w]+?);\s*\+\+\w+\s*\)'),
          r'for \1 in range(int(\2), int(\3)):', ['for']),
-        (re.compile(r'for\s*\(\s*\w+\s*(\w+)=(\w+);\s*\w+>([\.\->\w]+?);\s*--\w+\s*\)'),
+        (re.compile(r'\bfor\s*\(\s*\w+\s*(\w+)=(\w+);\s*\w+>([\.\->\w]+?);\s*--\w+\s*\)'),
          r'for \1 in range(int(\2), int(\3), -1):',
          ['for']),
-        (re.compile(r'for\s*\(\s*\w+\s*(\w+)=(\w+);\s*\w+<([\.\->\w]+?);\s*\w+\+=(\w+)\s*\)'),
+        (re.compile(r'\bfor\s*\(\s*\w+\s*(\w+)=(\w+);\s*\w+<([\.\->\w]+?);\s*\w+\+=(\w+)\s*\)'),
          r'for \1 in range(int(\2), int(\3), int(\4)):', ['for']),
-        (re.compile(r'for\s*\(\s*\w+\s*(\w+)=(\w+);\s*\w+>([\.\->\w]+?);\s*\w+-=(\w+)\s*\)'),
+        (re.compile(r'\bfor\s*\(\s*\w+\s*(\w+)=(\w+);\s*\w+>([\.\->\w]+?);\s*\w+-=(\w+)\s*\)'),
          r'for \1 in range(int(\2), int(\3), -int(\4)):', ['for']),
-        (re.compile(r'for\s*\(auto&&\s*\[(\w+),\s*(\w+)\]\s*:\s*(.+)\)'),
+        (re.compile(r'\bfor\s*\(auto&&\s*\[(\w+),\s*(\w+)\]\s*:\s*(.+)\)'),
          r'for \1, \2 in \3.items():' if sys.version_info[0] == 3 else r'for \1, \2 in \3.iteritems():', ['for']),
         (re.compile(r'\bwhile\s*\((.+)\)'), r'while(\1):', ['while']),
-        (re.compile(r'else\s+if\s*\(\s*(.+)\s*\)'), r'elif \1:', ['else']),
-        (re.compile(r'if\s*\(\s*(.+)\s*\)'), r'if \1:', ['if']),
-        (re.compile(r'if\s*!(.+):'), r'if not \1:', ['if']),
-        (re.compile(r'else'), r'else:', ['else']),
+        (re.compile(r'\belse\s+if\s*\(\s*(.+)\s*\)'), r'elif \1:', ['else']),
+        (re.compile(r'\bif\s*\(\s*(.+)\s*\)'), r'if \1:', ['if']),
+        (re.compile(r'\bif\s*!(.+):'), r'if not \1:', ['if']),
+        (re.compile(r'\belse\b'), r'else:', ['else']),
         (re.compile(r'std::string (\w+);'), r'\1 = ""', ['std::string']),
         (re.compile(r'(\w+)\s+(\w+);'), r'\2 = \1()'),
         (re.compile(r'(\w+) = return\(\)'), r'return \1', ['return']),
@@ -109,19 +109,19 @@ class RegexPatternPython(object):
         (re.compile(r'(\w)->'), r'\1.'),
         (re.compile(r'\+\+(\w+)'), r'\1 += 1'),
         (re.compile(r'(\w+)\+\+'), r'\1 += 1'),
-        (re.compile(r'delete (\w*);'), 'pass'),
+        (re.compile(r'\bdelete\b (\w*);'), 'pass'),
         (re.compile(r'&(\w+)'), r'\1'),
         (re.compile(r'!(\w+)'), r'not \1'),
         (re.compile(r'!\('), r'not ('),
         (re.compile(r'make_intrusive<(\w+)>\(\)'), r'make_intrusive(\1)', ['make_intrusive']),
-        (re.compile(r'new\s*(\w+)\s*\(\s*?\)'), r'make_intrusive(\1)', ['new']),
-        (re.compile(r'new\s*(\w+)\s*\((.*?)\)'), r'make_intrusive(\1, \2)', ['new']),
-        (re.compile(r'assert\(.+\);'), r'', ['assert ']),
+        (re.compile(r'\bnew\s*(\w+)\s*\(\s*?\)'), r'make_intrusive(\1)', ['new']),
+        (re.compile(r'\bnew\s*(\w+)\s*\((.*?)\)'), r'make_intrusive(\1, \2)', ['new']),
+        (re.compile(r'\bassert\(.+\);'), r'', ['assert ']),
         (re.compile(r'(\b[-0-9]+)\.f\b'), r'\1.0'),
         (re.compile(r'(\b[-0-9]+)\.([-0-9]*)f\b'), r'\1.\2'),
         (re.compile(r'([*+-/\s])log\((.+?)\)'), r'\1math.log(\2)', ['log']),
-        (re.compile(r'random_float\(\)'), 'random.random()', ['random_float']),
-        (re.compile(r'random_int\((.+)?,\s*(.+)?\)'), r'random.randint(\1, \2 - 1)', ['random_int']),
+        (re.compile(r'\brandom_float\(\)'), 'random.random()', ['random_float']),
+        (re.compile(r'\brandom_int\((.+)?,\s*(.+)?\)'), r'random.randint(\1, \2 - 1)', ['random_int']),
         (re.compile(r'\bthis\b'), r'self', ['this']),
         (re.compile(r', std::placeholders::_\d'), r'', ['std::placeholders']),
         (re.compile(r'dynamic_pointer_cast_intrusive<(\w+),\s*(\w+)>\((.+?)\)'),
@@ -137,10 +137,10 @@ class RegexPatternPython(object):
         (re.compile(r'\.at\((.*?)\)'), r'[\1]', ['at']),
 
         # Exception with try/catch block (one catch)
-        (re.compile(r'try\n\s*{([\s\S.]+?)}\n\s*catch\(((\w+)\s*(\w*))\)\n\s+{([\s\S.]+?)}'),
+        (re.compile(r'\btry\n\s*{([\s\S.]+?)}\n\s*catch\(((\w+)\s*(\w*))\)\n\s+{([\s\S.]+?)}'),
          r'try:\n{\n\1\n}\nexcept BaseException as \4:\n{\n\5\n}\n', ['try']),
-        (re.compile(r'throw Exception\((.*?)\)'), r'raise BaseException()', ['throw']),
-        (re.compile(r'throw make_intrusive\(Exception\)'), r'raise BaseException()', ['throw']),
+        (re.compile(r'\bthrow Exception\((.*?)\)'), r'raise BaseException()', ['throw']),
+        (re.compile(r'\bthrow make_intrusive\(Exception\)'), r'raise BaseException()', ['throw']),
         (re.compile(r'mg_swap\((.+)\s*,\s*(.+)\)'), r'\1, \2 = \2, \1', ['mg_swap']),
     )
 
